@@ -1,8 +1,7 @@
 import os
-from src.utils.file_control import load_dict_from_file
 
 
-def _find_reference(link, base_file_path):
+def _find_reference(link, base_file_path, file_control):
     if '#/' in link:
         file_path, item_path = link.split('#/')
         items = item_path.split('/')
@@ -10,7 +9,7 @@ def _find_reference(link, base_file_path):
         file_path, items = link, []
     spec_file = base_file_path if file_path == '' else os.path.join(os.path.dirname(base_file_path), file_path)
     try:
-        spec = load_dict_from_file(spec_file)
+        spec = file_control.load_dict_from_file(spec_file)
         for key in items:
             spec = spec[key]
         return spec, spec_file
@@ -19,15 +18,15 @@ def _find_reference(link, base_file_path):
         return '', spec_file
 
 
-def resolver(file_path, data):
+def resolver(file_path, data, file_control):
     if not isinstance(data, dict):
         return data
 
     for key, value in data.items():
         if key == '$ref':
-            new_value, base_file_path = _find_reference(value, file_path)
-            data = resolver(base_file_path, new_value)
+            new_value, base_file_path = _find_reference(value, file_path, file_control)
+            data = resolver(base_file_path, new_value, file_control)
         else:
-            new_value = resolver(file_path, value)
+            new_value = resolver(file_path, value, file_control)
             data[key] = new_value
     return data
